@@ -23,7 +23,7 @@ class RegularExpression:
         return self.original
 
     def _ndfa_e(self, ast):
-        if isinstance(ast, list):
+        if isinstance(ast, tuple):
             if len(ast) == 3:
                 fst = self._ndfa_e(ast[0])
                 snd = self._ndfa_e(ast[2])
