@@ -17,7 +17,7 @@ class FiniteAutomaton:
     :param delta: List of transitions with the form tupla of tupla of q_i and a, and q_f (default is empty).
     :param force: If True and states or symbols do not exists create them (default is False).
     :type force: bool
-    :param epsilon: The Finite Automaton includes epsilon (default is False)
+    :param epsilon: The Finite Automaton includes epsilon (default is None)
     :type epsilon: bool
     """
 
@@ -25,8 +25,9 @@ class FiniteAutomaton:
         self, Q=[], sigma=[], q_0=None, A=[], delta=[], force=False, epsilon=False
     ):
         self.sigma = OrderedSet()
+        self.e = epsilon
         if epsilon:
-            self.sigma.add("ε")
+            self.sigma.add(epsilon)
         self.sigma.update(sigma)
         self.Q = OrderedSet(Q)
         self.set_initial_state(q_0, force=force)
@@ -87,7 +88,7 @@ class FiniteAutomaton:
 
         :returns: Symbols of machine
         :rtype: list"""
-        return list(self.sigma)
+        return list(a for a in self.sigma if not a == self.e)
 
     def _transition(self, nq_i, na, nq_f):
         """Gets transition triplet given the index of states and symbol
@@ -164,19 +165,21 @@ class FiniteAutomaton:
             else:
                 print(f"{states.get(q,q)}", end=",\n ", **args)
 
-    def add_transition(self, q_i, a, q_f, force=False):
+    def add_transition(self, q_i, a, q_f, force=False, update=False):
         """Adds a transition
 
         :param q_i: Source state
         :param a: Symbol
         :param q_f: Destination state
+        :params force: Forces the creation of new symbols or states
+        :params update: If transition exists, updates it
         :returns: None"""
         if a == "epsilon":
             a = "ε"
         try:
             na = self._nsymbol(a)
         except KeyError:
-            if force:
+            if force and not a is "ε":
                 na = self.add_symbol(a)
             else:
                 raise DoesNotExistsSymbol(a)
@@ -188,8 +191,6 @@ class FiniteAutomaton:
             else:
                 raise DoesNotExistsState(q_i)
 
-        if nq_i and nq_i in self.ttable and na in self.ttable[nq_i]:
-            raise AlreadyExistsTransition(q_i, a, self)
         try:
             nq_f = self._nstate(q_f)
         except KeyError:
@@ -197,11 +198,18 @@ class FiniteAutomaton:
                 nq_f = self.add_state(q_f)
             else:
                 raise DoesNotExistsState(q_f)
-        try:
-            self.ttable[nq_i][na] = nq_f
-        except KeyError:
-            self.ttable[nq_i] = {}
-            self.ttable[nq_i][na] = nq_f
+
+        if nq_i and nq_i in self.ttable and na in self.ttable[nq_i]:
+            if update:
+                self.ttable[nq_i][na].update(nq_f)
+            else:
+                raise AlreadyExistsTransition(q_i, a, self)
+        else:
+            try:
+                self.ttable[nq_i][na] = nq_f
+            except KeyError:
+                self.ttable[nq_i] = {}
+                self.ttable[nq_i][na] = nq_f
 
     def add_state(self, q, initial=False):
         """Adds a state
@@ -477,7 +485,10 @@ class FiniteAutomaton:
                 if not nq in self.ttable:
                     empty_cell = True
                     break
-                elif not na in self.ttable[nq] or (isinstance(self.ttable[nq][na],set) and len(self.ttable[nq][na]) == 0):
+                elif not na in self.ttable[nq] or (
+                    isinstance(self.ttable[nq][na], set)
+                    and len(self.ttable[nq][na]) == 0
+                ):
                     empty_cell = True
                     break
             if empty_cell:
@@ -486,10 +497,15 @@ class FiniteAutomaton:
             self.add_state(e_label)
             for nq, q in enumerate(self.Q):
                 for na, a in enumerate(self.sigma):
-                    if not nq in self.ttable or \
-                            not na in self.ttable[nq] or \
-                            (isinstance(self.ttable[nq][na],set) and len(self.ttable[nq][na]) == 0):
-                        self.add_transition(q,a,e_label, force=True)
+                    if (
+                        not nq in self.ttable
+                        or not na in self.ttable[nq]
+                        or (
+                            isinstance(self.ttable[nq][na], set)
+                            and len(self.ttable[nq][na]) == 0
+                        )
+                    ):
+                        self.add_transition(q, a, e_label, force=True)
 
     def reachable_states(self):
         """Calculate the set of states which are reacheble
@@ -526,10 +542,9 @@ class FiniteAutomaton:
         :returns: List of unreachable states"""
         self.remove_states(self.unreachable_states())
 
-    def save_file(self, filename="machine.txt", order_Q=None, order_sigma=None):
-        """Saves a file
+    def to_string(self, order_Q=None, order_sigma=None):
+        """Creates a string
 
-        :param filename: Name of filename (default is machine.txt)
         :param order_Q: Order to print states
         :param order_sigma: Order to print vocabulary
 
@@ -546,41 +561,51 @@ class FiniteAutomaton:
             order_Q = list(self.Q)
         if not order_sigma:
             order_sigma = list(self.sigma)
+        strings=[]
+        # Alphabet line
+        strings.append(
+                    " " * (largest_q + 2)+"|"+"|".join(
+                        "{: ^{width}}".format(a, width=largest_cell) for a in self.sigma)+"|")
+        # Printing states
+        for q_i in order_Q:
+            q_l = q_i
+            if q_i == self.q_0:
+                q_l = f"->{q_i}"
+            if q_i in self.A:
+                q_l = f"{q_l}]"
+            if q_i == self.q_0:
+                strings.append(
+                    " {: <{width}}|".format(q_l, width=largest_q + 1))
+            else:
+                strings.append(
+                    "   {: <{width}}|".format(q_l, width=largest_q - 1))
+            line = []
+            for a in order_sigma:
+                try:
+                    s=self[(q_i, a)]
+                    if isinstance(s,set):
+                        line.append(",".join(s))
+                    else:
+                        line.append(s)
+                except DoesNotExistsTransition:
+                    line.append("")
+            r = "|".join("{: ^{width}}".format(c, width=largest_cell) for c in line)
+            strings[-1]+=r+"|"
+        return "\n".join(strings)
+
+
+    def save_file(self, filename="machine.txt", order_Q=None, order_sigma=None):
+        """Saves a file
+
+        :param filename: Name of filename (default is machine.txt)
+        :param order_Q: Order to print states
+        :param order_sigma: Order to print vocabulary
+
+        :returns: None
+        """
+        string=self.to_string(order_Q=order_Q,order_sigma=order_sigma)
         with open(filename, "w") as f:
-            print(" " * (largest_q + 2), end="", file=f)
-            print("|", end="", file=f)
-            h = "|".join(
-                "{: ^{width}}".format(a, width=largest_cell) for a in self.sigma
-            )
-            print(h, end="", file=f)
-            print("|", file=f)
-            for q_i in order_Q:
-                q_l = q_i
-                if q_i == self.q_0:
-                    q_l = f"->{q_i}"
-                if q_i in self.A:
-                    q_l = f"{q_l}]"
-                if q_i == self.q_0:
-                    print(
-                        " {: <{width}}|".format(q_l, width=largest_q + 1),
-                        end="",
-                        file=f,
-                    )
-                else:
-                    print(
-                        "   {: <{width}}|".format(q_l, width=largest_q - 1),
-                        end="",
-                        file=f,
-                    )
-                line = []
-                for a in order_sigma:
-                    try:
-                        line.append(",".join(self[(q_i, a)]))
-                    except DoesNotExistsTransition:
-                        line.append("")
-                r = "|".join("{: ^{width}}".format(c, width=largest_cell) for c in line)
-                print(r, end="", file=f)
-                print("|", file=f)
+            f.write(string)
 
     def save_img(
         self,
