@@ -24,8 +24,8 @@ class NonDeterministicFiniteAutomaton_epsilon(FiniteAutomaton):
     """
 
     def __init__(self, Q=[], sigma=[], q_0=None, A=[], delta=[], force=False):
-        super().__init__(Q, sigma, q_0, A, delta, epsilon=True)
-        self.e = "ε"
+        super().__init__(Q, sigma, q_0, A, delta, epsilon=epsilon)
+        self.e = epsilon
 
     def expansion_epsilon(self, qs):
         """Applies expansion by epsilon in a set of states
@@ -100,7 +100,8 @@ class NonDeterministicFiniteAutomaton_epsilon(FiniteAutomaton):
         :returns: List with summary"""
         info = [
             "States  : " + ", ".join([symbols.get(q, q) for q in self.states()]),
-            "Sigma   : " + ", ".join([symbols.get(a, a) for a in self.symbols()]),
+            "Sigma   : "
+            + ", ".join([symbols.get(a, a) for a in self.symbols() if not a == self.e]),
             "Initial : " + symbols.get(self.q_0, self.q_0),
             f"Aceptors: {{{', '.join([symbols.get(q, q) for q in self.A])}}}",
             "Transitions:",
