@@ -9,6 +9,13 @@ from ordered_set import OrderedSet
 
 
 def ndfa_e2ndfa(ndfa_e, rename=True, remove_sink=True):
+    """Reduces a NDFA-e to a NDFA
+
+    :param ndfa_e: NDFA-e to reduce
+    :param raname: Rename states after reduction
+    :param remove_sink: Remove sink states after reduction
+    """
+
     ndfa = NDFA()
 
     extra_A = set()
@@ -38,6 +45,13 @@ def codify_state(Q, s):
 
 
 def ndfa2dfa(ndfa, rename=True, remove_sink=True):
+    """Reduces a NDFA to a DFA
+
+    :param ndfa: NDFA to reduce
+    :param raname: Rename states after reduction
+    :param remove_sink: Remove sink states after reduction
+    """
+
     dfa = DFA()
     max_size = len(ndfa.Q) + 1
     initial_state = set([ndfa.q_0])
@@ -81,6 +95,13 @@ def ndfa2dfa(ndfa, rename=True, remove_sink=True):
 
 
 def dfa2ndfa_e(dfa, rename=True, remove_sink=True):
+    """Reduces a DFA to a NDFA-e
+
+    :param dfa: DFA to reduce
+    :param raname: Rename states after reduction
+    :param remove_sink: Remove sink states after reduction
+    """
+
     ndfa_e = NDFA_e()
     ndfa_e.Q = OrderedSet(dfa.Q)
     ndfa_e.sigma.update(dfa.sigma)
@@ -103,6 +124,13 @@ def dfa2ndfa_e(dfa, rename=True, remove_sink=True):
 
 
 def ndfa_e2dfa(ndfa_e, rename=True, remove_sink=True):
+    """Reduces a NDFA-e to a DFA
+
+    :param dfa: NDFA-e to reduce
+    :param raname: Rename states after reduction
+    :param remove_sink: Remove sink states after reduction
+    """
+
     return ndfa2dfa(
         ndfa_e2ndfa(ndfa_e, rename=rename, remove_sink=remove_sink),
         rename=rename,
@@ -111,6 +139,13 @@ def ndfa_e2dfa(ndfa_e, rename=True, remove_sink=True):
 
 
 def ndfa2ndfa_e(ndfa, rename=True, remove_sink=True):
+    """Reduces a NDFA to a NDFA-e
+
+    :param dfa: NDFA to reduce
+    :param raname: Rename states after reduction
+    :param remove_sink: Remove sink states after reduction
+    """
+
     return dfa2ndfa_e(
         ndfa2dfa(ndfa, rename=rename, remove_sink=remove_sink),
         rename=rename,
@@ -119,6 +154,12 @@ def ndfa2ndfa_e(ndfa, rename=True, remove_sink=True):
 
 
 def dfa2ndfa(dfa, rename=True, remove_sink=True):
+    """Reduces a DFA to a NDFA
+
+    :param dfa: DFA to reduce
+    :param raname: Rename states after reduction
+    :param remove_sink: Remove sink states after reduction
+    """
     return ndfa_e2ndfa(
         dfa2ndfa_e(dfa, rename=rename, remove_sink=remove_sink),
         rename=rename,
